==> declic.iledefrance_20170122_0515.tgz: var/www/vhosts/declic.iledefrance.fr/htdocs/wp-config.php <==
<?php
/**
 * La configuration de base de votre installation WordPress.
 *
 * Ce fichier contient les réglages de configuration suivants : réglages MySQL,
 * préfixe de table, clefs secrètes, langue utilisée, et ABSPATH.
 * Vous pouvez en savoir plus à leur sujet en allant sur
 * {@link http://codex.wordpress.org/fr:Modifier_wp-config.php Modifier
 * wp-config.php}. C'est votre hébergeur qui doit vous donner vos
 * codes MySQL.
 *
 * Ce fichier est utilisé par le script de création de wp-config.php pendant
 * le processus d'installation. Vous n'avez pas à utiliser le site web, vous
 * pouvez simplement renommer ce fichier en "wp-config.php" et remplir les
 * valeurs.
 *
 * @package WordPress
 */

// ** Réglages MySQL - Votre hébergeur doit vous fournir ces informations. ** //
/** Nom de la base de données de WordPress. */

define('DB_NAME', 'declic-iledefra');
define('DB_USER', 'declic-iledefra');
define('DB_PASSWORD', 'XwkDwqDl29dzQC');
define('DB_HOST', 'localhost');
define('DB_CHARSET', 'utf8mb4');

/*
define('DB_NAME', 'bruSuXa3ast');
define('DB_USER', 'bruSuXa3ast');
define('DB_PASSWORD', 'rjr3XIX2vYSBFC');
define('DB_HOST', 'localhost'); // vps1.agence-ultramedia.com
define('DB_CHARSET', 'utf8mb4');
 */
define('DB_COLLATE', '');

/**#@+
 * Clefs uniques d'authentification et salage.
 *
 * Remplacez les valeurs par défaut par des phrases uniques !
 * Vous pouvez générer des phrases aléatoires en utilisant
 * {@link https://api.wordpress.org/secret-key/1.1/salt/ le service de clefs secrètes de WordPress.org}.
 * Vous pouvez modifier ces phrases à n'importe quel moment, afin d'invalider tous les cookies existants.
 * Cela forcera également tous les utilisateurs à se reconnecter.
 *
 * @since 2.6.0
 */
define('AUTH_KEY',         'X<}C`%h29=/h>yW6:?i&Q9vAO$`sMF`[xb~Ojktd0w-H{av:+foNcjBc@9UV,7K/');
define('SECURE_AUTH_KEY',  'nAoVTpRvbY=Fq dw!qWI|,4ypo,@FSA=7ZPMlC5^7<oCq)crf/8d702_[/>n.F];');
define('LOGGED_IN_KEY',    'X&]fzGQQjyVQq7,kt6;3dM*Ct91(kk~5PQJHqY2DthEZSlT.TY*W]~$dEx35Yq;L');
define('NONCE_KEY',        'm?Jc&F,NUHRl`*oKtelu29|YxSC>8.J`D7H#Ztc@824=__}KM4-A-LSa6[qIAFKD');
define('AUTH_SALT',        'z&9dNj59&SaLxRC>YxU#TdJ!a6@*H[u;Q:320mX$+gozq8K8Pvz]7hh;2ak5:P%4');
define('SECURE_AUTH_SALT', '_1$*PhO2)$f#lud&)`(2,>P]<:jSk.6U:&6D0 vU_82vU>`E68(;=9QA;?//pVQK');
define('LOGGED_IN_SALT',   '#>0*MXi2ubL]/j!RE&k}ul?AUid@B1)07QTg@{qBR0>xnqPE;d<PJCu:~8WbTDO8');
define('NONCE_SALT',       'ohDf%SM#T!uQc2c<bi`_>XZ|){_iY`k52;Nj+liVM&x=T$5m@bd$6.|Y@; =[7VJ');
/**#@-*/

/**
 * Préfixe de base de données pour les tables de WordPress.
 *
 * Vous pouvez installer plusieurs WordPress sur une seule base de données
 * si vous leur donnez chacune un préfixe unique.
 * N'utilisez que des chiffres, des lettres non-accentuées, et des caractères soulignés!
 */
$table_prefix  = 'wp_';

/**
 * Pour les développeurs : le mode déboguage de WordPress.
 *
 * En passant la valeur suivante à "true", vous activez l'affichage des
 * notifications d'erreurs pendant vos essais.
 * Il est fortemment recommandé que les développeurs d'extensions et
 * de thèmes se servent de WP_DEBUG dans leur environnement de
 * développement.
 *
 * Pour plus d'information sur les autres constantes qui peuvent être utilisées
 * pour le déboguage, rendez-vous sur le Codex.
 * 
 * @link https://codex.wordpress.org/Debugging_in_WordPress 
 */
define('WP_DEBUG', false);
/* C'est tout, ne touchez pas à ce qui suit ! Bon blogging ! */

/** Chemin absolu vers le dossier de WordPress. */
if ( !defined('ABSPATH') )
	define('ABSPATH', dirname(__FILE__) . '/');

/** Réglage des variables de WordPress et de ses fichiers inclus. */
require_once(ABSPATH . 'wp-settings.php');

==> declic.iledefrance_20170219_0515.tgz: var/www/vhosts/declic.iledefrance.fr/htdocs/wp-config.php <==
<?php
/**
 * La configuration de base de votre installation WordPress.
 *
 * Ce fichier contient les réglages de configuration suivants : réglages MySQL,
 * préfixe de table, clefs secrètes, langue utilisée, et ABSPATH.
 * Vous pouvez en savoir plus à leur sujet en allant sur
 * {@link http://codex.wordpress.org/fr:Modifier_wp-config.php Modifier
 * wp-config.php}. C'est votre hébergeur qui doit vous donner vos
 * codes MySQL.
 *
 * Ce fichier est utilisé par le script de création de wp-config.php pendant
 * le processus d'installation. Vous n'avez pas à utiliser le site web, vous
 * pouvez simplement renommer ce fichier en "wp-config.php" et remplir les
 * valeurs.
 *
 * @package WordPress
 */

// ** Réglages MySQL - Votre hébergeur doit vous fournir ces informations. ** //
/** Nom de la base de données de WordPress. */

define('WP_CACHE', true); //Added by WP-Cache Manager
define( 'WPCACHEHOME', '/var/www/vhosts/declic.iledefrance.fr/htdocs/wp-content/plugins/wp-super-cache/' ); //Added by WP-Cache Manager
define('DB_NAME', 'declic-iledefra');
define('DB_USER', 'declic-iledefra');
define('DB_PASSWORD', 'XwkDwqDl29dzQC');
define('DB_HOST', 'localhost');
define('DB_CHARSET', 'utf8mb4');

/*
define('DB_NAME', 'bruSuXa3ast');
define('DB_USER', 'bruSuXa3ast');
define('DB_PASSWORD', 'rjr3XIX2vYSBFC');
define('DB_HOST', 'localhost'); // vps1.agence-ultramedia.com
define('DB_CHARSET', 'utf8mb4');
 */
define('DB_COLLATE', '');

/**#@+
 * Clefs uniques d'authentification et salage.
 *
 * Remplacez les valeurs par défaut par des phrases uniques !
 * Vous pouvez générer des phrases aléatoires en utilisant
 * {@link https://api.wordpress.org/secret-key/1.1/salt/ le service de clefs secrètes de WordPress.org}.
 * Vous pouvez modifier ces phrases à n'importe quel moment, afin d'invalider tous les cookies existants.
 * Cela forcera également tous les utilisateurs à se reconnecter.
 *
 * @since 2.6.0
 */
define('AUTH_KEY',         'X<}C`%h29=/h>yW6:?i&Q9vAO$`sMF`[xb~Ojktd0w-H{av:+foNcjBc@9UV,7K/');
define('SECURE_AUTH_KEY',  'nAoVTpRvbY=Fq dw!qWI|,4ypo,@FSA=7ZPMlC5^7<oCq)crf/8d702_[/>n.F];');
define('LOGGED_IN_KEY',    'X&]fzGQQjyVQq7,kt6;3dM*Ct91(kk~5PQJHqY2DthEZSlT.TY*W]~$dEx35Yq;L');
define('NONCE_KEY',        'm?Jc&F,NUHRl`*oKtelu29|YxSC>8.J`D7H#Ztc@824=__}KM4-A-LSa6[qIAFKD');
define('AUTH_SALT',        'z&9dNj59&SaLxRC>YxU#TdJ!a6@*H[u;Q:320mX$+gozq8K8Pvz]7hh;2ak5:P%4');
define('SECURE_AUTH_SALT', '_1$*PhO2)$f#lud&)`(2,>P]<:jSk.6U:&6D0 vU_82vU>`E68(;=9QA;?//pVQK');
define('LOGGED_IN_SALT',   '#>0*MXi2ubL]/j!RE&k}ul?AUid@B1)07QTg@{qBR0>xnqPE;d<PJCu:~8WbTDO8');
define('NONCE_SALT',       'ohDf%SM#T!uQc2c<bi`_>XZ|){_iY`k52;Nj+liVM&x=T$5m@bd$6.|Y@; =[7VJ');
/**#@-*/

/**
 * Préfixe de base de données pour les tables de WordPress.
 *
 * Vous pouvez installer plusieurs WordPress sur une seule base de données
 * si vous leur donnez chacune un préfixe unique.
 * N'utilisez que des chiffres, des lettres non-accentuées, et des caractères soulignés!
 */
$table_prefix  = 'wp_';

/**
 * Pour les développeurs : le mode déboguage de WordPress.
 *
 * En passant la valeur suivante à "true", vous activez l'affichage des
 * notifications d'erreurs pendant vos essais.
 * Il est fortemment recommandé que les développeurs d'extensions et
 * de thèmes se servent de WP_DEBUG dans leur environnement de
 * développement.
 *
 * Pour plus d'information sur les autres constantes qui peuvent être utilisées
 * pour le déboguage, rendez-vous sur le Codex.
 * 
 * @link https://codex.wordpress.org/Debugging_in_WordPress 
 */
define('WP_DEBUG', false);
/* C'est tout, ne touchez pas à ce qui suit ! Bon blogging ! */

/** Chemin absolu vers le dossier de WordPress. */
if ( !defined('ABSPATH') )
	define('ABSPATH', dirname(__FILE__) . '/');

/** Réglage des variables de WordPress et de ses fichiers inclus. */
require_once(ABSPATH . 'wp-settings.php');
